Overview
========

A Django web front-end that provides user registration and password
reset to an LDAP server.

.. figure:: https://www.kenet.or.ke/sites/default/files/kenelogomedium.png
   :alt: KENET Research Services

..

   **Created by:** `KENET Research Services`_

   **License:** GPLv3

Features
--------

1. User self registration with email account activation
2. User self password reset (typical email reset workflow)

.. _KENET Research Services: https://www.kenet.or.ke/research-services